@@ -21,12 +21,15 @@
 
 #include "osdep/macosx_events.h"
 #include "osdep/macosx_compat.h"
-
-#include "video/out/cocoa/additions.h"
 #include "video/out/cocoa_common.h"
 
 #include "window.h"
 
+@interface MpvVideoWindow()
+- (NSRect)frameRect:(NSRect)frameRect forCenteredContentSize:(NSSize)newSize;
+- (void)setCenteredContentSize:(NSSize)newSize;
+@end
+
 @implementation MpvVideoWindow {
     NSSize _queued_video_size;
 }
@@ -47,13 +50,9 @@
     return self;
 }
 
-- (void)windowDidResize:(NSNotification *) notification
-{
-    [self.adapter setNeedsResize];
-}
-
 - (void)windowDidChangeBackingProperties:(NSNotification *)notification
 {
+    // XXX: we maybe only need expose for this
     [self.adapter setNeedsResize];
 }
 
@@ -62,24 +61,14 @@
     [self.adapter didChangeWindowedScreenProfile:[self screen]];
 }
 
-- (BOOL)isInFullScreenMode
+- (void)windowDidResignKey:(NSNotification *)notification
 {
-    return !!([self styleMask] & NSFullScreenWindowMask);
+    [self.adapter windowDidResignKey:notification];
 }
 
-- (void)setFullScreen:(BOOL)willBeFullscreen
+- (void)windowDidBecomeKey:(NSNotification *)notification
 {
-    if (willBeFullscreen != [self isInFullScreenMode]) {
-        [super toggleFullScreen:nil];
-    }
-}
-
-- (void)toggleFullScreen:(id)sender {
-    if ([self isInFullScreenMode]) {
-        [self.adapter putCommand:"set fullscreen no"];
-    } else {
-        [self.adapter putCommand:"set fullscreen yes"];
-    }
+    [self.adapter windowDidBecomeKey:notification];
 }
 
 - (BOOL)canBecomeMainWindow { return YES; }
@@ -123,9 +112,6 @@
 
 - (NSRect)constrainFrameRect:(NSRect)nf toScreen:(NSScreen *)screen
 {
-    if ([self isInFullScreenMode])
-        return [super constrainFrameRect:nf toScreen:screen];
-
     NSRect of  = [self frame];
     NSRect vf  = [screen ?: self.screen ?: [NSScreen mainScreen] visibleFrame];
     NSRect ncf = [self contentRectForFrameRect:nf];
@@ -166,6 +152,7 @@
     if (_queued_video_size.width <= 0.0 || _queued_video_size.height <= 0.0)
         return;
 
+    // XXX find a way to kill this state
     if (![self.adapter isInFullScreenMode]) {
         [self setContentAspectRatio:_queued_video_size];
         [self setCenteredContentSize:_queued_video_size];
@@ -184,20 +171,4 @@
 - (void)windowDidBecomeMain:(NSNotification *)notification {
     [self tryDequeueSize];
 }
-
-- (NSSize)window:(NSWindow *)window willUseFullScreenContentSize:(NSSize)size {
-    return window.screen.frame.size;
-}
-
-- (NSApplicationPresentationOptions)window:(NSWindow *)window
-      willUseFullScreenPresentationOptions:(NSApplicationPresentationOptions)opts {
-    return NSApplicationPresentationFullScreen      |
-           NSApplicationPresentationAutoHideDock    |
-           NSApplicationPresentationAutoHideMenuBar |
-           NSApplicationPresentationAutoHideToolbar;
-}
-
-- (void)windowDidExitFullScreen:(NSNotification *)notification {
-    [self tryDequeueSize];
-}
 @end
