@@ -172,12 +172,14 @@ def build(ctx):
         ( "demux/demux_libass.c",                "libass"),
         ( "demux/demux_mf.c" ),
         ( "demux/demux_mkv.c" ),
+        ( "demux/demux_mkv_timeline.c" ),
         ( "demux/demux_playlist.c" ),
         ( "demux/demux_raw.c" ),
         ( "demux/demux_subreader.c" ),
         ( "demux/demux_tv.c",                    "tv" ),
         ( "demux/ebml.c" ),
         ( "demux/packet.c" ),
+        ( "demux/timeline.c" ),
 
         ## Input
         ( "input/cmd_list.c" ),
@@ -222,9 +224,6 @@ def build(ctx):
         ( "player/screenshot.c" ),
         ( "player/scripting.c" ),
         ( "player/sub.c" ),
-        ( "player/timeline/tl_cue.c" ),
-        ( "player/timeline/tl_mpv_edl.c" ),
-        ( "player/timeline/tl_matroska.c" ),
         ( "player/video.c" ),
 
         ## Streams
